var mongoose = require('../mongoose.js')();
var _ = require('lodash');
var crypto = require('crypto');

var schema = new mongoose.Schema({
  customerId: {
    type: String,
    require: true
  },
  userId: {
    type: mongoose.Schema.ObjectId,
    require: true
  },
  data: Object,
  email: String,

  unsubscribeToken: String,
  unsubscribed: { type: Boolean, default: false },

  modified: { type: Date, default: Date.now },
  created: { type: Date, default: Date.now }
});

schema.pre('save', function(next) {
  if (this.isNew) {
    this.unsubscribeToken = crypto.randomBytes(16).toString('hex');
  }
  next();
});

schema.virtual('id').get(function() {
  if (this._id) {
    return this._id.toHexString();
  }
  return null;
});

schema.set('toJSON', {
  virtuals: true
});

schema.index({userId: 1, customerId: 1}, {unique: true});

module.exports = mongoose.model('ApiCustomer', schema, 'api_customers');
